import socket
import logging

import msgpack


class QriPython:

    def __init__(self, host=None, port=None):
        self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)

        try:
            self.sock.connect((host, port))
        except socket.error, msg:
            logging.error("[QRI-PY] Server {0}:{1} unreachable: {2}".format(host, port, msg))

    def send(self, peer=None, checksum=None, message=None):
        packed_data = msgpack.packb([peer, checksum, message])

        try:
            self.sock.send(packed_data)
        except socket.error, msg:
            logging.error("[QRI-PY] Error occurred during sending: {0}".format(msg))

    def close(self):
        self.sock.close()



#!/usr/bin/env python

from distutils.core import setup


setup(
    name='qri-py',
    version='1.0.0',
    description='Qri Python interface',
    author='va-dev',
    author_email='vadimanikin1@gmail.com',
    url='https://github.com/Orderry/qri-py',
    packages=['qri_py'],
    package_dir={'qri_py': 'src/qri_py'},
    install_requires=['msgpack-python']
)
